@@ -13,14 +13,12 @@
 #include "kalarmapp.h"
 #include "kamail.h"
 #include "mainwindow.h"
-#include "messagewindow.h"
 #include "preferences.h"
 #include "resourcescalendar.h"
-#include "templatelistview.h"
 #include "resources/calendarfunctions.h"
 #include "resources/datamodel.h"
-#include "resources/resources.h"
 #include "resources/eventmodel.h"
+#include "resources/resources.h"
 #include "lib/autoqpointer.h"
 #include "lib/dragdrop.h"
 #include "lib/filedialog.h"
@@ -67,6 +65,7 @@ using namespace KCalendarCore;
 #include <QStandardPaths>
 #include <QPushButton>
 #include <QTemporaryFile>
+#include <kwidgetsaddons_version.h>
 
 //clazy:excludeall=non-pod-global-static
 
@@ -1382,7 +1381,7 @@ void editNewTemplate(EditAlarmDlg::Type type, const KAEvent& preset, QWidget* pa
 {
     if (Resources::enabledResources(CalEvent::TEMPLATE, true).isEmpty())
     {
-        KAMessageBox::sorry(parent, i18nc("@info", "You must enable a template calendar to save the template in"));
+        KAMessageBox::error(parent, i18nc("@info", "You must enable a template calendar to save the template in"));
         return;
     }
     // Use AutoQPointer to guard against crash on application exit while
@@ -1612,7 +1611,11 @@ void outputAlarmWarnings(QWidget* parent, const KAEvent* event)
         if (KAMessageBox::warningYesNo(parent, xi18nc("@info", "<para>Alarms are currently disabled.</para><para>Do you want to enable alarms now?</para>"),
                                        QString(), KGuiItem(i18nc("@action:button", "Enable")), KGuiItem(i18nc("@action:button", "Keep Disabled")),
                                        QStringLiteral("EditEnableAlarms"))
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                        == KMessageBox::ButtonCode::PrimaryAction)
+#else
                         == KMessageBox::Yes)
+#endif
             theApp()->setAlarmsEnabled(true);
     }
 }
