@@ -142,7 +142,7 @@ class KADateTimeSpecPrivate;
  * @see <a href="http://www.w3.org/TR/timezone/">W3C: Working with Time Zones</a>
  * @author David Jarvie \<djarvie@kde.org\>.
  */
-class KALARMCAL_EXPORT KADateTime //krazy:exclude=dpointer (implicitly shared)
+class KALARMCAL_EXPORT KADateTime
 {
 public:
     /**
@@ -192,7 +192,7 @@ public:
          *
          * @param tz  time zone
          */
-        Spec(const QTimeZone& tz);   // allow implicit conversion
+        Spec(const QTimeZone& tz);   //cppcheck-suppress noExplicitConstructor; Allow implicit conversion
 
         /**
          * Constructs a time specification.
@@ -201,7 +201,7 @@ public:
          * @param utcOffset number of seconds to add to UTC to get the local
          *                  time. Ignored if @p type is not @c OffsetFromUTC.
          */
-        Spec(SpecType type, int utcOffset = 0);   // allow implicit conversion
+        Spec(SpecType type, int utcOffset = 0);   //cppcheck-suppress noExplicitConstructor; Allow implicit conversion
 
         /**
          * Copy constructor.
