@@ -1,7 +1,7 @@
 /*
  *  preferences.cpp  -  program preference settings
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -10,15 +10,16 @@
 
 #include "kalarm.h"
 #include "kamail.h"
+#include "pluginmanager.h"
 #include "lib/desktop.h"
 #include "lib/messagebox.h"
+#include "kalarmcalendar/identities.h"
 #include "kalarm_debug.h"
 
-#include <KAlarmCal/Identities>
-
 #include <KIdentityManagement/Identity>
 #include <KIdentityManagement/IdentityManager>
 #include <KHolidays/HolidayRegion>
+#include <kpimtextedit/kpimtextedit-texttospeech.h>
 
 #include <KSharedConfig>
 #include <KConfigGroup>
@@ -102,6 +103,30 @@ Preferences::Preferences()
     setVersion(QStringLiteral(KALARM_VERSION));
 }
 
+/******************************************************************************
+* Get whether the Akonadi plugin should be used, if available.
+*/
+bool Preferences::useAkonadi()
+{
+    return self()->mUseAkonadiIfAvailable  &&  PluginManager::instance()->akonadiPlugin();
+}
+
+/******************************************************************************
+* Return the Akonadi plugin to use, or null if not being used or not available.
+*/
+AkonadiPlugin* Preferences::akonadiPlugin()
+{
+    if (!self()->mUseAkonadiIfAvailable)
+        return nullptr;
+    return PluginManager::instance()->akonadiPlugin();
+}
+
+void Preferences::setUseAkonadi(bool yes)
+{
+    if (PluginManager::instance()->akonadiPlugin())
+        self()->setUseAkonadiIfAvailable(yes);
+}
+
 /******************************************************************************
 * Auto hiding of the system tray icon is only allowed on desktops which provide
 * GUI controls to show hidden icons.
@@ -377,6 +402,34 @@ void Preferences::workTimeChange(const QDateTime& start, const QDateTime& end, i
     Q_EMIT mInstance->workTimeChanged(start.time(), end.time(), dayBits);
 }
 
+Preferences::MailClient Preferences::emailClient()
+{
+    if (!useAkonadi())
+        return sendmail;
+    return static_cast<MailClient>(self()->mBase_EmailClient);
+}
+
+void Preferences::setEmailClient(MailClient client)
+{
+    if (!useAkonadi())
+        client = sendmail;
+    self()->setBase_EmailClient(client);
+}
+
+bool Preferences::emailCopyToKMail()
+{
+    if (!useAkonadi())
+        return false;
+    return self()->mBase_EmailCopyToKMail  &&  static_cast<MailClient>(self()->mBase_EmailClient) == sendmail;
+}
+
+void Preferences::setEmailCopyToKMail(bool yes)
+{
+    if (!useAkonadi())
+        yes = false;
+    self()->setBase_EmailCopyToKMail(yes);
+}
+
 Preferences::MailFrom Preferences::emailFrom()
 {
     const QString from = self()->mBase_EmailFrom;
@@ -454,6 +507,24 @@ void Preferences::setCmdXTermCommand(const QString& cmd)
     self()->setBase_CmdXTermCommand(translateXTermPath(cmd, true));
 }
 
+Preferences::SoundType Preferences::defaultSoundType()
+{
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
+    return self()->base_DefaultSoundType();
+#else
+    SoundType type = self()->base_DefaultSoundType();
+    return (type == Sound_Speak) ? Sound_None : type;
+#endif
+}
+
+void Preferences::setDefaultSoundType(SoundType type)
+{
+#if !KPIMTEXTEDIT_TEXT_TO_SPEECH
+    if (type == Sound_Speak)
+        return;
+#endif
+    self()->setBase_DefaultSoundType(type);
+}
 
 void Preferences::connect(const char* signal, const QObject* receiver, const char* member)
 {
